package cz.kebrt.unitcheck.ant;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.Task;
import org.apache.tools.ant.types.Path;
import org.apache.tools.ant.types.Reference;
import org.apache.tools.ant.util.ClasspathUtils;

import cz.kebrt.unitcheck.UnitChecker;
import cz.kebrt.unitcheck.config.Config;
import cz.kebrt.unitcheck.config.ConfigException;
import cz.kebrt.unitcheck.config.TestConfig;
import cz.kebrt.unitcheck.runner.ConsoleUnitCheckListener;
import cz.kebrt.unitcheck.util.ContextClassPathFactory;
import cz.kebrt.unitcheck.util.PathPrinter;

/**
 * ffd
 * @author michal
 *
 */
public class UnitCheckTask extends Task {

	private String baseDir;
	private String testClass;
	private String testMethod;
	private String configFile;
	private boolean filterJUnitTrace = true;
	private boolean printPath = true;
	private boolean printBytecode = false;
	private boolean traceJRE = false;

	ClasspathUtils.Delegate vmClasspath;
	ClasspathUtils.Delegate vmSourcepath;

	private ClassLoader backupCl;

	@Override
	public void init() {
		this.vmClasspath = ClasspathUtils.getDelegate(this);
		this.vmSourcepath = ClasspathUtils.getDelegate(this);
		super.init();
	}

	@Override
	public void execute() throws BuildException {
		try {
			backupCl = Thread.currentThread().getContextClassLoader();
			Thread.currentThread().setContextClassLoader(this.getClass().getClassLoader());

			Config config = createConfig();
			PathPrinter.Config pathConfig = new PathPrinter.Config(traceJRE, printBytecode);

			UnitChecker uc = new UnitChecker(config);
			uc.addListener(new ConsoleUnitCheckListener(System.out, pathConfig,
					printPath));

			uc.run();
		} catch (ConfigException e) {
			System.out.println(e.getMessage());
			throw new BuildException(e.getMessage());
		} finally {
			Thread.currentThread().setContextClassLoader(backupCl);
		}
	}

	public void setBaseDir(String dir) {
		this.baseDir = dir;
	}

	public void setTestClass(String klass) {
		this.testClass = klass;
	}

	public void setVMClasspathRef(Reference r) {
		this.vmClasspath.setClasspathref(r);
	}

	public Path createVMClasspath() {
		return this.vmClasspath.createClasspath();
	}

	public void setVMSourcepathRef(Reference r) {
		this.vmSourcepath.setClasspathref(r);
	}

	public Path createVMSourcepath() {
		return this.vmSourcepath.createClasspath();
	}

	private Config createConfig() throws ConfigException {
		Config config = new Config();

		if (vmClasspath.getClasspath() != null) {
			List<String> cp = Arrays.asList(vmClasspath.getClasspath().list());
			config.setVMClasspath(cp);
			ClassLoader cl = ContextClassPathFactory.create(cp);
			Thread.currentThread().setContextClassLoader(cl);
		}

		config.setLibDir(baseDir);
		config.setOneTest(new TestConfig(testClass, testMethod));

		List<String> sourcePath = null;
		if (vmSourcepath.getClasspath() != null) {
			sourcePath = Arrays.asList(vmSourcepath.getClasspath().list());
		} else {
			sourcePath = new ArrayList<String>();
		}
		config.setFilterJUnitTrace(filterJUnitTrace);
		config.setJPFConfigFile(configFile);
		config.setVMSourcepath(sourcePath);

		return config;
	}

	public String getBaseDir() {
		return baseDir;
	}

	public String getTestClass() {
		return testClass;
	}

	public void setFilterJUnitTrace(boolean filterJUnitTrace) {
		this.filterJUnitTrace = filterJUnitTrace;
	}

	public void setPrintPath(boolean printPath) {
		this.printPath = printPath;
	}

	public void setPrintBytecode(boolean printBytecode) {
		this.printBytecode = printBytecode;
	}

	public void setTraceJRE(boolean traceJRE) {
		this.traceJRE = traceJRE;
	}

	public void setTestMethod(String testMethod) {
		this.testMethod = testMethod;
	}

	public void setConfigFile(String configFile) {
		this.configFile = configFile;
	}

}