/**
 * Data structures exposed by UnitCheck to 3rd party programs.
 * <p>
 * Most of structures are dual to structures provided by JUnit and JPF. There are
 * a couple of reasons why custom structures are used instead of the original ones.
 * <ul>
 *  <li>Some of the JUnit structures (living in the model layer) do not provide
 *      public constructors so they cannot be reconstructed in the Java layer.
 *  <li>JPF MJI interface allows to access instances
 *      of modeled classes using fields (calling methods is an experimental feature). See
 *      the <code>cz.kebrt.unitcheck.junit.holder</code> package for additional
 *      information about this  problem.
 *  <li>JPF structures are very large and provide access to internal structures of JPF
 *      (e.g. they allow to control the state space traversal). Structures provided
 *      by UnitCheck contain only information relevant to the execution of tests
 *      and do not allow to touch JPF itself.
 *  <li>Some custom structures provide more convenient way of accessing information
 *      (e.g. bidirectional traversal of transitions).
 * </ul>
 * <p>
 * Structures that appear in the code together with the original structures are suffixed
 * with <code>Holder</code>.
 */
package cz.kebrt.unitcheck.api.data;

