package cz.kebrt.unitcheck.util;

import java.util.ArrayList;
import java.util.List;

/**
 * Builds a classpath string from a list of elements. Elements are separated with a string
 * passed in the get() method.
 *
 * @author michal
 *
 */
public class ClassPathBuilder {

    public static final String COMMA_SEPARATOR = ",";

    private final List<String> elements = new ArrayList<String>();

    /**
     * Adds a list of strings to the classpath.
     *
     * @param list
     */
    public void add(List<String> list) {
        elements.addAll(list);
    }

    /**
     * Adds a single string to the classpath.
     *
     * @param element
     */
    public void add(String element) {
        elements.add(element);
    }

    /**
     * Returns classpath with elements previously added in the builder. The elements are
     * separated with a string passed as an argument.
     *
     * @param separator separator of classpath elements
     * @return string containing all classpath elements separated with the specified
     *         separator
     */
    public String get(String separator) {
        StringBuilder sb = new StringBuilder();
        for (int i = 0; i < elements.size(); ++i) {
            sb.append(elements.get(i));
            if (i < (elements.size() - 1)) {
                sb.append(separator);
            }
        }
        return sb.toString();
    }

}
