package cz.kebrt.unitcheck.util;

/**
 * Holder for another object of type T. To be used in situations where a
 * <code>final</code> variable is required by Java syntax but needs to be modified (e.g.
 * when using a local variable the from outer type in an anonymous class).
 *
 * @author michal
 *
 * @param <T>
 */
public class ObjectHolder<T> {

    private T obj;

    /**
     * Cstr. Assigns <code>null</code> as underlying object.
     */
    public ObjectHolder() {
        obj = null;
    }

    /**
     * Assigns object in the holder.
     *
     * @param obj object to be assigned in the holder
     */
    public ObjectHolder(T obj) {
        super();
        this.obj = obj;
    }

    /**
     * Returns object kept by the holder.
     *
     * @return object kept by the holder
     */
    public T get() {
        return obj;
    }

    /**
     * Sets object kept by the holder.
     *
     * @param obj object to be assigned in the holder
     */
    public void set(T o) {
        this.obj = o;
    }

}
